@@ -43,6 +43,13 @@ class Client(object):
         self._validate_client()
         self.is_grantless = is_grantless
 
+        print('SPAPIClient::redis_config', redis_config)
+        if not redis_config:
+            redis_config = {
+                'host': 'redis',
+                'port': 6379,
+                'db': 0
+            }
         self.cache = redis.StrictRedis(**redis_config)
         self.redis_lock = RedisLock(self.cache)
 
