@@ -4,7 +4,6 @@ import string
 import time
 from collections import namedtuple
 
-import redis
 from redis.exceptions import RedisError
 
 string_type = getattr(__builtins__, 'basestring', str)
@@ -38,20 +37,9 @@ class RedisLock(object):
         return 0
     end"""
 
-    def __init__(self, connection_list, retry_count=None, retry_delay=None):
-        self.servers = []
-        for connection_info in connection_list:
-            try:
-                if isinstance(connection_info, string_type):
-                    server = redis.StrictRedis.from_url(connection_info)
-                elif type(connection_info) == dict:
-                    server = redis.StrictRedis(**connection_info)
-                else:
-                    server = connection_info
-                self.servers.append(server)
-            except Exception as e:
-                raise Warning(str(e))
-        self.quorum = (len(connection_list) // 2) + 1
+    def __init__(self, redis_server, retry_count=None, retry_delay=None):
+        self.servers = [redis_server]
+        self.quorum = (len(self.servers) // 2) + 1
 
         if len(self.servers) < self.quorum:
             raise CannotObtainLock(
